function [centered key] = gmm_bs(data,reps,seed,study)
    % Read in data
    N_w = data(:,1);
	  N_b = data(:,2);
	  C_w = data(:,3);
	  C_b = data(:,4);
    F   = data(:,5);

    % Compute probabilities
    n   = sum(F);
    dd  = dummyvar(findgroups(N_w,N_b));
    bb  = F./(dd*(dd'*F));
    pp  = (dd*(dd'*F))/sum(F);

    % Compute bootstrap replications
    rng(seed)
    bg = gamrnd(repmat(F,[1,reps]),1);
    bg = bg./(dd*(dd'*bg));

    % Construct constraint matrix
	  for i = 1:length(bb)
        t = zeros(max(N_w)+1,max(N_b)+1);
        for j = C_w(i):N_w(i)
            for k = C_b(i):N_b(i)
                t(j+1,k+1) = (-1)^(j-C_w(i))*nchoosek(N_w(i),C_w(i))*nchoosek(N_w(i)-C_w(i),j-C_w(i))* ...
                             (-1)^(k-C_b(i))*nchoosek(N_b(i),C_b(i))*nchoosek(N_b(i)-C_b(i),k-C_b(i));
            end
        end
	    mm(i,:) = t(:)';
    end

    % Drop unused moments & store labels
    p_w   = repmat((0:max(N_w))',[1 max(N_b)+1]); p_w = p_w(:);
    p_b   = repmat((0:max(N_b)) ,[max(N_w)+1 1]); p_b = p_b(:);
    [h,l] = size(mm);
    for i = 1:l
        if  mm(:,i) == zeros(h,1)
            tmp(i)  =  0;
        else
            tmp(i)  =  1;
        end
    end
    p_w = p_w( tmp' == 1); p_w = p_w(2:end);
    p_b = p_b( tmp' == 1); p_b = p_b(2:end);
    mm  = mm(:,tmp  == 1);

    % Restrict to separately-identified moments (eliminate collinearity)
    m  = mm(C_w + C_b > 0 & bb > 0,2:end);
    bs = bg(C_w + C_b > 0 & bb > 0,:);
    d  = dd(C_w + C_b > 0 & bb > 0,:);
    p  = pp(C_w + C_b > 0 & bb > 0);
    b  = bb(C_w + C_b > 0 & bb > 0);

    % Constraint vectors
    [h,l] = size(m);
    Aeq   = [m eye(h)];
    lb    = [-Inf*ones(1,h+l)];

    % QP CMD estimation (probabilty-weighted)
    [G_cmd,~] = quadprog_gurobi(blkdiag(zeros(l),diag(p)),  [],[],[],Aeq,b,lb,[]);
    V         = diag(m*G_cmd(1:l))-(d.*(m*G_cmd(1:l)))*(d.*(m*G_cmd(1:l)))';
    [G_omd,~] = quadprog_gurobi(blkdiag(zeros(l),p.*inv(V)),[],[],[],Aeq,b,lb,[]);
    [centered key] = recenter([p_w p_b G_omd(1:l) G_omd(1:l)],study);

    % Bootstrap replications
    tic
    parfor i = 1:reps
        disp(['Repitition ',num2str(i),':'])
        [G_cmd,~] = quadprog_gurobi(blkdiag(zeros(l),diag(p)),  [],[],[],Aeq,bs(:,i),lb,[]);
         V        = diag(m*G_cmd(1:l))-(d.*(m*G_cmd(1:l)))*(d.*(m*G_cmd(1:l)))';
        [G_omd,~] = quadprog_gurobi(blkdiag(zeros(l),p.*inv(V)),[],[],[],Aeq,bs(:,i),lb,[]);
        [bs_centered(:,i) bs_key(:,i)] = recenter([p_w p_b G_omd(1:l) G_omd(1:l)],study);
    end
    toc

    % Collect results
    centered        = [p_w p_b centered sqrt(diag(cov(bs_centered')')/n)]
    key             = [key sqrt(diag(cov(bs_key')')/n)]
end
