function [J df G ests se] = gmm_ests(data)
    % Read in data
    N_w = data(:,1);
  	N_b = data(:,2);
	  C_w = data(:,3);
	  C_b = data(:,4);
    F   = data(:,5);

    % Compute probabilities
    dd  = dummyvar(findgroups(N_w,N_b));
    bb  = F./(dd*(dd'*F));
    pp  = (dd*(dd'*F))/sum(F);

    % Compute fraction within each callback strata
    e         = dummyvar(findgroups(N_w,N_b,C_w+C_b+1));
    designs   = unique([N_w N_b],'rows');
    [num_d,~] = size(designs);
    g         = mean(N_w+N_b);
    str_info  = [kron(designs,ones(g+1,1)) repmat((0:g)',[num_d 1])];
    str_raw   = e'*bb;

    % Construct constraint matrix
  	for i = 1:length(bb)
        t = zeros(max(N_w)+1,max(N_b)+1);
        for j = C_w(i):N_w(i)
            for k = C_b(i):N_b(i)
                t(j+1,k+1) = (-1)^(j-C_w(i))*nchoosek(N_w(i),C_w(i))*nchoosek(N_w(i)-C_w(i),j-C_w(i))* ...
                             (-1)^(k-C_b(i))*nchoosek(N_b(i),C_b(i))*nchoosek(N_b(i)-C_b(i),k-C_b(i));
            end
        end
	    mm(i,:) = t(:)';
    end

    % Drop unused moments & store labels
    p_w   = repmat((0:max(N_w))',[1 max(N_b)+1]); p_w = p_w(:);
    p_b   = repmat((0:max(N_b)) ,[max(N_w)+1 1]); p_b = p_b(:);
    [h,l] = size(mm);
    for i = 1:l
        if  mm(:,i) == zeros(h,1)
            tmp(i)  =  0;
        else
            tmp(i)  =  1;
        end
    end
    p_w = p_w( tmp' == 1); p_w = p_w(2:end);
    p_b = p_b( tmp' == 1); p_b = p_b(2:end);
    mm  = mm(:,tmp  == 1);

    % Restrict to separately-identified moments (eliminate collinearity)
    m = mm(C_w + C_b > 0 & bb > 0,2:end);
    d = dd(C_w + C_b > 0 & bb > 0,:);
    p = pp(C_w + C_b > 0 & bb > 0);
    b = bb(C_w + C_b > 0 & bb > 0);

    % Constraint vectors
    [h,l] = size(m);
    Aeq   = [m eye(h)];
    beq   = [b];
    lb    = [-Inf*ones(1,h+l)];

    % QP CMD estimation (probabilty-weighted)
    W               = blkdiag(zeros(l),diag(p));
    [G_cmd J_cmd]   = quadprog_gurobi(W,[],[],[],Aeq,beq,lb,[]);
    G_cmd           = G_cmd(1:l);
    b_cmd           = mm*[1;G_cmd];

    % Construct VCV matrix of moment estimates
    V = diag(m*G_cmd)-(d.*(m*G_cmd))*(d.*(m*G_cmd))'; % Model-based variance;
    %V = diag(b)-(d.*b)*(d.*b)'+(d.*(m*G_cmd-b))*(d.*(m*G_cmd-b))';  % Pseudo-true;

    % QP OMD estimatation (full inverse-VCV weighted)
    W               = blkdiag(zeros(l),p.*inv(V));
    [G_omd J_omd]   = quadprog_gurobi(W,[],[],[],Aeq,beq,lb,[]);
    G_omd           = G_omd(1:l);
    b_omd           = mm*[1;G_omd];

    % Collect results
    J    = [J_cmd J_omd]*sum(F);
    G    = [p_w p_b G_cmd G_omd];
    ests = [N_w N_b C_w C_b bb b_cmd b_omd];
    df   = [h l];
    se   = [   sqrt(diag(diag(mm*[1;G_omd])-(dd.*(mm*[1;G_omd]))*(dd.*(mm*[1;G_omd]))')/sum(F))];
    se   = [se sqrt(diag(diag(mm*[1;G_omd])-(dd.*(mm*[1;G_omd]))*(dd.*(mm*[1;G_omd]))')./(pp*sum(F)))];
end
