function [L] = likelihood_j(theta,data,sims,model,ncovs);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%% UNPACK ARGUMENTS %%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

        %%%%Data;
         l=1;
         id=data(:,l); l=l+1;
         Y=data(:,l); l=l+1;
         D=data(:,l); l=l+1;
         X=data(:,l:(l+ncovs-1)); l=l+ncovs;
         X_D=data(:,l:end);
         N=length(Y);
         R=length(sims(:,1));
         
        %%%Classify model being estimated;
        continuous=isequal(model,'norm_restrict') + isequal(model,'lognorm_restrict') + isequal(model,'chisq_restrict') ...
                      + isequal(model,'norm') + isequal(model,'lognorm') + isequal(model,'chisq');
        restrict=isequal(model,'norm_restrict') + isequal(model,'lognorm_restrict') + isequal(model,'chisq_restrict') ...
                      + isequal(model,'types_restrict');
        types=isequal(model,'types') + isequal(model,'types_restrict');
        chisq=isequal(model,'chisq') + isequal(model,'chisq_restrict');
        lognorm=isequal(model,'lognorm') + isequal(model,'lognorm_restrict');
         

        %%%%Parameters to be estimated;
        l=1;
        alpha_0=theta(l); l=l+1;
        sigma_alpha=exp(theta(l)); l=l+1;
        beta_0=theta(l); l=l+1;
        sigma_beta=0; rho=0; beta_2=0;
        if continuous==1;
            sigma_beta=exp(theta(l)); l=l+1;
            if restrict==0;
                rho=(exp(2*theta(l))-1)/(exp(2*theta(l))+1); l=l+1;
            end;
            if chisq==1;
                beta_2=theta(l); l=l+1;
            end;
        end;
        if types==1;
            delta_0=theta(l); l=l+1;
            delta_alpha=0;
            if restrict==0;
                delta_alpha=theta(l); l=l+1;
            end;
        end;
        gamma=theta(l:(l+ncovs-1)); l=l+ncovs;
        gamma_D=theta(l:end);
       

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%% COMPUTE LIKELIHOOD %%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
        %%%Process random coefficients;
        z1=sims(:,1);
        z2=rho*sims(:,1) + sqrt(1-(rho^2))*sims(:,2);
        alpha=alpha_0+sigma_alpha*z1;
        beta=beta_0 + sigma_beta*z2 + beta_2*(z2.^2);
        if lognorm==1;
           beta = exp(beta);
        end;
        pi_type=ones(R,1);
        if types==1;
            u_type = delta_0 + delta_alpha*(alpha - alpha_0);
            pi_type=1./(1+exp(-u_type));
        end;
        
        
        %%%Likelihood;
        Y_big=repmat(Y,[1 R]);
        beta_big=repmat(beta',[N 1]);
        beta_big = beta_big + (beta_big~=0).*(X_D*gamma_D);
        U_0 = repmat(alpha',[N 1])+repmat(X*gamma,[1 R]);
        U_1 = U_0 - repmat(D,[1 R]).*beta_big;
        Lambda_0 = 1./(1+exp(-U_0));
        Lambda_1 = 1./(1+exp(-U_1));
        L_0 = prod(Y_big.*Lambda_0 + (1-Y_big).*(1-Lambda_0),1)';
        L_1 = prod(Y_big.*Lambda_1 + (1-Y_big).*(1-Lambda_1),1)';
        L = mean(L_1.*pi_type + L_0.*(1-pi_type));
