function bounds = lp_bounds(data,bb,p_w,p_b,c)
    % Read in data
    N_w = data(:,1);
	  N_b = data(:,2);
	  C_w = data(:,3);
	  C_b = data(:,4);

    % Compute fraction within each callback strata
    e         = dummyvar(findgroups(N_w,N_b,C_w+C_b+1));
    designs   = unique([N_w N_b],'rows');
    [num_d,~] = size(designs);
    g         = mean(N_w+N_b);
    str       = [kron(designs,ones(g+1,1)) repmat((0:g)',[num_d 1]) e'*bb];

    % Construct probability grid and constraint matrix
	  for i = 1:length(bb)
	    t = binopdf(C_w(i),N_w(i),p_w).*binopdf(C_b(i),N_b(i),p_b);
	    mm(i,:) = t';
    end

    % Construct constraint matrices
    m = mm(C_w + C_b > 0 & bb > 0,:);
    b = bb(C_w + C_b > 0 & bb > 0);
    u = ones( size(p_b))';
    l = zeros(size(p_b))';

    % LP Bounds estimation: Trace
	  [~,tr_max] = linprog_gurobi(-(p_w == p_b),    [],[],[m;u;c'],[b;1;1],l,u);
    for o = 0:g
        f = binopdf(o,g,p_b).*(p_w == p_b);
        [~, bounds_tr(o+1,1)] = linprog_gurobi(-f,[],[],[m;u;c'],[b;1;1],l,u);
    end
    bounds_tr = [-tr_max; kron(ones(num_d,1),-bounds_tr)./str(:,4)];

    % LP Bounds estimation: Lower triangle
	  [~,lt_max] = linprog_gurobi(-(p_w <= p_b),    [],[],[m;u;c'],[b;1;1],l,u);
    for i = 1:length(str)
        f = zeros(size(p_b));
        for j = 0:str(i,3)
            f = f+binopdf(j,str(i,1),p_w).*binopdf(str(i,3)-j,str(i,2),p_b).*(p_w<=p_b);
        end
        [~, bounds_lt(i,1)] = linprog_gurobi(-f,  [],[],[m;u;c'],[b;1;1],l,u);
    end
    bounds_lt = [-lt_max; -bounds_lt./str(:,4)];

    % LP Bounds estimation: Upper triangle
	  [~,ut_max] = linprog_gurobi(-(p_w >= p_b),    [],[],[m;u;c'],[b;1;1],l,u);
    for i = 1:length(str)
        f = zeros(size(p_b));
        for j = 0:str(i,3)
            f = f+binopdf(j,str(i,1),p_w).*binopdf(str(i,3)-j,str(i,2),p_b).*(p_w>=p_b);
        end
        [~, bounds_ut(i,1)] = linprog_gurobi(-f,  [],[],[m;u;c'],[b;1;1],l,u);
    end
    bounds_ut = [-ut_max; -bounds_ut./str(:,4)];

    % Collect results
    bounds  = [[0 0 -1 1; str] bounds_tr bounds_lt bounds_ut];
end
