function [J J_bs p_val bs_reps] = qp_cns(data,p_w,p_b,reps,seed,c)
    % Read in data
    N_w = data(:,1);
	N_b = data(:,2);
	C_w = data(:,3);
	C_b = data(:,4);
    F   = data(:,5);

    % Compute probabilities
    dd  = dummyvar(findgroups(N_w,N_b));
    bb  = F./(dd*(dd'*F));
    pp  = (dd*(dd'*F))/sum(F);

    % Construct probability grid and constraint matrix
	for i = 1:length(bb)
	    t = binopdf(C_w(i),N_w(i),p_w).*binopdf(C_b(i),N_b(i),p_b);
	    mm(i,:) = t';
    end

    % Compute bootstrap replications
    rng(seed)
    bs_reps = gamrnd(repmat(F,[1,reps]),1);
    bs_reps = bs_reps./(dd*(dd'*bs_reps));

    % Restrict to separately-identified moments (eliminate collinearity)
    bs = bs_reps(C_w + C_b > 0 & bb > 0,:);
    m  = mm(C_w + C_b > 0 & bb > 0,:);
    d  = dd(C_w + C_b > 0 & bb > 0,:);
    p  = pp(C_w + C_b > 0 & bb > 0,:);
    b  = bb(C_w + C_b > 0 & bb > 0,:);

    % Store useful matrices
    u   = ones( 1,length(p_b));
    l   = zeros(1,length(p_b));
    zsk = zeros(  length(p_b));
    k   = zeros(1,length(b  ));
    kk  = eye(    length(b  ));
    zkk = zeros(  length(b  ));
    zm  = zeros(  size(m    ));

    % Initial QP CMD estimation (probabilty-weighted) - store VCV matrix
    W           = sparse(blkdiag(sparse(zsk),sparse(diag(p))));
    [G, J_cmd]  = quadprog_gurobi(W,[],[],[],[u k; c' k; m kk],[1;1;b],[l -Inf*ones(size(b'))],[]);
    b_cmd       = m*G(1:length(p_b));
    V           = diag(b_cmd)-(d.*b_cmd)*(d.*b_cmd)';

    % QP OMD estimatation (full inverse-VCV weighted)
    W           = sparse(blkdiag(sparse(zsk),sparse(p.*inv(V))));
    [G, J_omd]  = quadprog_gurobi(W,[],[],[],[u k; c' k; m kk],[1;1;b],[l -Inf*ones(size(b'))],[]);
    b_omd       = m*G(1:length(p_b));

    % Save contstraint matrices
    lb          = [l l -Inf*ones(1,2*length(b))];
    Aeq         = sparse([m zm kk kk; zm m zkk kk; u l k k; l u k k; l c' k k]);
    Qc_omd      = sparse(blkdiag(sparse(zsk),sparse(zsk),sparse(zkk),sparse(p.*inv(V))));

    % Bootstrap replications
    tic
    parfor i = 1:reps
        disp(['Repitition ',num2str(i),':'])

        % Initial construction of BS VCV matrix
        [G, ~] = quadprog_gurobi(sparse(blkdiag(sparse(zsk),sparse(diag(p)))),[],[],[], ...
                                 [u k; c' k; m kk],[1;1;bs(:,i)],[l -Inf*ones(size(b'))],[]);
        bs_cmd = m*G(1:length(p_b));
        [~, J_omd_bs(i)]  = qcqp_gurobi(sparse(blkdiag(sparse(zsk),sparse(zsk), ...
                                        sparse(p.*inv(diag(bs_cmd)-(d.*bs_cmd)*(d.*bs_cmd)')), ...
                                        sparse(zkk))),[],[],[],Aeq,[bs(:,i);b;1;1;1],lb,[],Qc_omd,J_omd);
    end
    toc

    J       = sum(F)*J_omd;
    J_bs    = sum(F)*sort(J_omd_bs');
    p_val   = mean(J_bs >= J);
    bs_reps = bs_reps;
end
