function [moments J G] = qp_ests(data,p_w,p_b,lambda,c)
    % Read in data
    N_w = data(:,1);
	  N_b = data(:,2);
	  C_w = data(:,3);
	  C_b = data(:,4);
    F   = data(:,5);

    % Compute probabilities
    dd = dummyvar(findgroups(N_w,N_b));
    bb = F./(dd*(dd'*F));
    pp = (dd*(dd'*F))/sum(F);

    % Construct probability grid and constraint matrix
	  for i = 1:length(bb)
	    t = binopdf(C_w(i),N_w(i),p_w).*binopdf(C_b(i),N_b(i),p_b);
	    mm(i,:) = t';
    end

    % Restrict to separately-identified moments (eliminate collinearity)
    m = mm(C_w + C_b > 0 & bb > 0,:);
    d = dd(C_w + C_b > 0 & bb > 0,:);
    p = pp(C_w + C_b > 0 & bb > 0);
    b = bb(C_w + C_b > 0 & bb > 0);

    % Constraint vectors
    u   = ones( size(p_b))';
    l   = zeros(size(p_b))';
    Aeq = sparse([u zeros(size(b')); c' zeros(size(b')); m eye(length(b))]);
    beq = [1;1;b];
    lb  = [l -Inf*ones(size(b'))];
    ub  = [u  Inf*ones(size(b'))];

    % QP CMD estimation (probabilty-weighted)
    W               = sparse(blkdiag(sparse(lambda*eye(length(p_b))),sparse(diag(p))));
    f               = [-2*ones(length(p_b),1)/length(p_b);zeros(length(b),1)]*lambda;
    [G_cmd J_cmd]   = quadprog_gurobi(W,f,[],[],Aeq,beq,lb,ub);
    G_cmd           = G_cmd(1:length(p_b));

    % Construct VCV matrix of moment estimates
    V = diag(m*G_cmd)-(d.*(m*G_cmd))*(d.*(m*G_cmd))'; % Model-based variance;
    %V = diag(b)-(d.*b)*(d.*b)'+(d.*(m*G_cmd-b))*(d.*(m*G_cmd-b))'; % Pseudo-true;

    % QP OMD estimatation (full inverse-VCV weighted)
    W               = sparse(blkdiag(sparse(lambda*eye(length(p_b))),sparse(p.*inv(V))));
    f               = [-2*ones(length(p_b),1)/length(p_b);zeros(length(b),1)]*lambda;
    [G_omd J_omd]   = quadprog_gurobi(W,f,[],[],Aeq,beq,lb,ub);
    G_omd           = G_omd(1:length(p_b));

    % Collect results
    moments = [N_w N_b C_w C_b bb mm*G_cmd mm*G_omd]
    J       = [J_cmd J_omd]*sum(F)
    G       = [p_w p_b G_cmd G_omd];
end
