function [centered key J_bs_centered J_bs_key] = qp_num_bs(data,p_w,p_b,reps,seed,c,study)
    % Read in data
    N_w = data(:,1);
  	N_b = data(:,2);
  	C_w = data(:,3);
	  C_b = data(:,4);
    F   = data(:,5);

    % Compute probabilities
    n   = sum(F);
    e   = (1)*n^(-1/3);
    dd  = dummyvar(findgroups(N_w,N_b));
    bb  = F./(dd*(dd'*F));
    pp  = (dd*(dd'*F))/n;

    % Construct probability grid and constraint matrix
	  for i = 1:length(bb)
	    t = binopdf(C_w(i),N_w(i),p_w).*binopdf(C_b(i),N_b(i),p_b);
	    mm(i,:) = t';
    end

    % Compute bootstrap replications
    rng(seed)
    bg = gamrnd(repmat(F,[1,reps]),1);
    bg = bg./(dd*(dd'*bg));

    % Restrict to separately-identified moments (eliminate collinearity)
    bs = bg(C_w + C_b > 0 & bb > 0,:);
    m  = mm(C_w + C_b > 0 & bb > 0,:);
    d  = dd(C_w + C_b > 0 & bb > 0,:);
    p  = pp(C_w + C_b > 0 & bb > 0,:);
    b  = bb(C_w + C_b > 0 & bb > 0,:);

    % Constraint vectors
    u   = ones( size(p_b))';
    l   = zeros(size(p_b))';
    s   = length(p_b);
    Aeq = sparse([u zeros(size(b')); c' zeros(size(b')); m eye(length(b))]);
    lb  = [l -Inf*ones(size(b'))];
    W   = sparse(blkdiag(sparse(zeros(s)),sparse(diag(p))));

    % QP CMD estimation (probabilty-weighted)
    [G1, ~] = quadprog_gurobi(W,[],[],[],Aeq,[1;1;b],lb,[]);
    [G2, ~] = quadprog_gurobi(sparse(blkdiag(sparse(zeros(s)), ...
              sparse(p.*inv(diag(m*G1(1:s))-(d.*(m*G1(1:s)))*(d.*(m*G1(1:s)))')))),[],[],[],Aeq,[1;1;b],lb,[]);
    [~,~,moments,~,~] = gmm_ests([N_w N_b C_w C_b mm*G2(1:s)]);
    [centered key]    = recenter(moments,study);

    % Bootstrap replications
    tic
    parfor i = 1:reps
        disp(['Repitition ',num2str(i),':'])
            [G1, ~] = quadprog_gurobi(W,[],[],[],Aeq,[1;1;[(1-e*sqrt(n))*b+(e*sqrt(n))*bs(:,i)]],lb,[]);
            [G2, ~] = quadprog_gurobi(sparse(blkdiag(sparse(zeros(s)),                      ...
                      sparse(p.*inv(diag(m*G1(1:s))-(d.*(m*G1(1:s)))*(d.*(m*G1(1:s)))')))), ...
                      [],[],[],Aeq,[1;1;[(1-e*sqrt(n))*b+(e*sqrt(n))*bs(:,i)]],lb,[]);
            [~,~,moments,~,~] = gmm_ests([N_w N_b C_w C_b mm*G2(1:s)]);
            [bs_centered(:,i) bs_key(:,i)]  = recenter(moments,study);
    end
    toc

    J_bs_centered       = (e^-1)*(bs_centered-centered);
    J_bs_key            = (e^-1)*(bs_key-key);
    se_centered_num_bs  = sqrt(diag(cov(J_bs_centered')'/n));
    se_key_num_bs       = sqrt(diag(cov(J_bs_key')'/n));
    J_bs_c_sorted       = sort(J_bs_centered')';
    J_bs_k_sorted       = sort(J_bs_key')';
    lb_numbs_c          = J_bs_c_sorted(:,max(1,floor(0.05*reps)))/sqrt(n) + centered;
    ub_numbs_c          = J_bs_c_sorted(:,ceil( 0.95*reps))/sqrt(n) + centered;
    lb_numbs_k          = J_bs_k_sorted(:,max(1,floor(0.05*reps)))/sqrt(n) + key;
    ub_numbs_k          = J_bs_k_sorted(:,ceil( 0.95*reps))/sqrt(n) + key;
    centered            = [moments(:,1:2) centered se_centered_num_bs lb_numbs_c ub_numbs_c]
    key                 = [key se_key_num_bs lb_numbs_k ub_numbs_k]
end
