% Ben Scuderi
% Last Updated: 9/16/20
% Calculate Exact Goodness-of-Fit Tests for Callback Sequence Freq. Data
% Chamberlain-style test for binomial trials model
% Tests against uniform null (equal probability of observing each frequency)

% Basic setup -- clear and launch parallel pool if available, add path for functions
clear all;
delete(gcp('nocreate'))
try;
    parpool;
end;
addpath('functions')

% Read in 4-app spells data
agcv4 = readtable('../results/agcv_4app_sequence_freq.csv');
agcv4 = removevars(agcv4,{'seq','tot'});
agcv4((agcv4.num_c == 0 | agcv4.num_c == 4),:) = [];
agcv4 = table2array(agcv4);

% Read in 8-app spells data
agcv8 = readtable('../results/agcv_8app_sequence_freq.csv');
agcv8 = removevars(agcv8,{'seq','tot'});
agcv8((agcv8.num_c == 0 | agcv8.num_c == 8),:) = [];
agcv8 = table2array(agcv8);

% Calculate Exact p-values
[results4 counts4] = calc_p_exact(4,agcv4)
[results8 counts8] = calc_p_exact(8,agcv8)

% Write results to csv
outsheet([results4; results8], ...
    'n_apps,n_calls,n_obs,n_configs,validation,p_exact,p_chi2ex,p_ch2wt', ...
    '../results/agcv_chi2_exact_p_values.csv');

outsheet([counts4; counts8], ...
    'n_apps,n_calls,n_obs,n_configs,possibilites,sum_multiplicity', ...
    '../results/agcv_chi2_exact_counts.csv');
