% Ben Scuderi
% Last Updated: 9/16/2020
% Program to estimate sensitivity of bounds to grid choices

% I. PRELIMINARIES

% Setup - try parallell pool, add path for functions
clear all
delete(gcp('nocreate'))
try;
    parpool;
end;
addpath('functions')

% a. Insheet data
bm          = csvread('../data/bm_counts.csv',    1,0);
agcv        = csvread('../data/agcv_counts.csv',  1,0);
nunley      = csvread('../data/nunley_counts.csv',1,0);
nunley      = nunley(nunley(:,1)>0&nunley(:,2)>0,:); % Drop 0,4 and 4,0 designs;

% b. Insheet grid options
grid_q_K050 = csvread('../grids/logit_G_quadL_50.csv',  1,0);
grid_q_K100 = csvread('../grids/logit_G_quadL_100.csv', 1,0);
grid_q_K150 = csvread('../grids/logit_G_quadL_150.csv', 1,0);
grid_q_K200 = csvread('../grids/logit_G_quadL_200.csv', 1,0);
grid_q_K300 = csvread('../grids/logit_G_quadL_300.csv', 1,0);
grid_q_K400 = csvread('../grids/logit_G_quadL_400.csv', 1,0);
grid_q_K600 = csvread('../grids/logit_G_quadL_600.csv', 1,0);
grid_q_K900 = csvread('../grids/logit_G_quadL_900.csv', 1,0);
grid_r_K150 = csvread('../grids/grid_rect_K150.csv',    1,0);
grid_r_K900 = csvread('../grids/grid_rect_K900.csv',    1,0);


% I. BM

% a. First step moment estimates (K1)
[ests_q_K050_b,J_q_K050_b,~] = qp_ests(         bm,                       grid_q_K050(:,1),grid_q_K050(:,2),0,ones(size(grid_q_K050(:,1))));
[ests_q_K100_b,J_q_K100_b,~] = qp_ests(         bm,                       grid_q_K100(:,1),grid_q_K100(:,2),0,ones(size(grid_q_K100(:,1))));
[ests_q_K150_b,J_q_K150_b,~] = qp_ests(         bm,                       grid_q_K150(:,1),grid_q_K150(:,2),0,ones(size(grid_q_K150(:,1))));
[ests_r_K150_b,J_r_K150_b,~] = qp_ests(         bm,                       grid_r_K150(:,1),grid_r_K150(:,2),0,ones(size(grid_r_K150(:,1))));

% b. Second step bound estimates (K2>K1)
[bounds_q050_q200_b]         = lp_bounds_tronly(bm    ,ests_q_K050_b(:,7),grid_q_K200(:,1),grid_q_K200(:,2),  ones(size(grid_q_K200(:,1))));
[bounds_q100_q200_b]         = lp_bounds_tronly(bm    ,ests_q_K100_b(:,7),grid_q_K200(:,1),grid_q_K200(:,2),  ones(size(grid_q_K200(:,1))));
[bounds_q100_q400_b]         = lp_bounds_tronly(bm    ,ests_q_K100_b(:,7),grid_q_K400(:,1),grid_q_K400(:,2),  ones(size(grid_q_K400(:,1))));
[bounds_q100_q600_b]         = lp_bounds_tronly(bm    ,ests_q_K100_b(:,7),grid_q_K600(:,1),grid_q_K600(:,2),  ones(size(grid_q_K600(:,1))));
[bounds_q150_q300_b]         = lp_bounds_tronly(bm    ,ests_q_K150_b(:,7),grid_q_K300(:,1),grid_q_K300(:,2),  ones(size(grid_q_K300(:,1))));
[bounds_q150_q600_b]         = lp_bounds_tronly(bm    ,ests_q_K150_b(:,7),grid_q_K600(:,1),grid_q_K600(:,2),  ones(size(grid_q_K600(:,1))));
[bounds_q150_q900_b]         = lp_bounds_tronly(bm    ,ests_q_K150_b(:,7),grid_q_K900(:,1),grid_q_K900(:,2),  ones(size(grid_q_K900(:,1))));
[bounds_r150_r900_b]         = lp_bounds_tronly(bm    ,ests_r_K150_b(:,7),grid_r_K900(:,1),grid_r_K900(:,2),  ones(size(grid_r_K900(:,1))));

% c. Report Results
bounds_b                     = [ 50 200 J_q_K050_b(2) 1-bounds_q050_q200_b(1,5) 1-bounds_q050_q200_b(3:5,5)' ; ...
                                100 200 J_q_K100_b(2) 1-bounds_q100_q200_b(1,5) 1-bounds_q100_q200_b(3:5,5)' ; ...
                                100 400 J_q_K100_b(2) 1-bounds_q100_q400_b(1,5) 1-bounds_q100_q400_b(3:5,5)' ; ...
                                100 600 J_q_K100_b(2) 1-bounds_q100_q600_b(1,5) 1-bounds_q100_q600_b(3:5,5)' ; ...
                                150 300 J_q_K150_b(2) 1-bounds_q150_q300_b(1,5) 1-bounds_q150_q300_b(3:5,5)' ; ...
                                150 600 J_q_K150_b(2) 1-bounds_q150_q600_b(1,5) 1-bounds_q150_q600_b(3:5,5)' ; ...
                                150 900 J_q_K150_b(2) 1-bounds_q150_q900_b(1,5) 1-bounds_q150_q900_b(3:5,5)' ; ...
                                150 900 J_r_K150_b(2) 1-bounds_r150_r900_b(1,5) 1-bounds_r150_r900_b(3:5,5)' ] ;

outsheet(bounds_b,'K1,K2,J,overall,one_call,two_calls,three_calls','../results/grid_sensitivity_bm.csv');


% II. AGCV

% a. First step moment estimates (K1)
[ests_q_K050_a,J_q_K050_a,~] = qp_ests(         agcv,                     grid_q_K050(:,1),grid_q_K050(:,2),0,ones(size(grid_q_K050(:,1))));
[ests_q_K100_a,J_q_K100_a,~] = qp_ests(         agcv,                     grid_q_K100(:,1),grid_q_K100(:,2),0,ones(size(grid_q_K100(:,1))));
[ests_q_K150_a,J_q_K150_a,~] = qp_ests(         agcv,                     grid_q_K150(:,1),grid_q_K150(:,2),0,ones(size(grid_q_K150(:,1))));
[ests_r_K150_a,J_r_K150_a,~] = qp_ests(         agcv,                     grid_r_K150(:,1),grid_r_K150(:,2),0,ones(size(grid_r_K150(:,1))));

% b. Second step bound estimates (K2>K1)
[bounds_q050_q200_a]         = lp_bounds_tronly(agcv  ,ests_q_K050_a(:,7),grid_q_K200(:,1),grid_q_K200(:,2),  ones(size(grid_q_K200(:,1))));
[bounds_q100_q200_a]         = lp_bounds_tronly(agcv  ,ests_q_K100_a(:,7),grid_q_K200(:,1),grid_q_K200(:,2),  ones(size(grid_q_K200(:,1))));
[bounds_q100_q400_a]         = lp_bounds_tronly(agcv  ,ests_q_K100_a(:,7),grid_q_K400(:,1),grid_q_K400(:,2),  ones(size(grid_q_K400(:,1))));
[bounds_q100_q600_a]         = lp_bounds_tronly(agcv  ,ests_q_K100_a(:,7),grid_q_K600(:,1),grid_q_K600(:,2),  ones(size(grid_q_K600(:,1))));
[bounds_q150_q300_a]         = lp_bounds_tronly(agcv  ,ests_q_K150_a(:,7),grid_q_K300(:,1),grid_q_K300(:,2),  ones(size(grid_q_K300(:,1))));
[bounds_q150_q600_a]         = lp_bounds_tronly(agcv  ,ests_q_K150_a(:,7),grid_q_K600(:,1),grid_q_K600(:,2),  ones(size(grid_q_K600(:,1))));
[bounds_q150_q900_a]         = lp_bounds_tronly(agcv  ,ests_q_K150_a(:,7),grid_q_K900(:,1),grid_q_K900(:,2),  ones(size(grid_q_K900(:,1))));
[bounds_r150_r900_a]         = lp_bounds_tronly(agcv  ,ests_r_K150_a(:,7),grid_r_K900(:,1),grid_r_K900(:,2),  ones(size(grid_r_K900(:,1))));

% c. Report Results
bounds_a                     = [ 50 200 J_q_K050_a(2) 1-bounds_q050_q200_a(1,5) 1-bounds_q050_q200_a(3:5,5)' ; ...
                                100 200 J_q_K100_a(2) 1-bounds_q100_q200_a(1,5) 1-bounds_q100_q200_a(3:5,5)' ; ...
                                100 400 J_q_K100_a(2) 1-bounds_q100_q400_a(1,5) 1-bounds_q100_q400_a(3:5,5)' ; ...
                                100 600 J_q_K100_a(2) 1-bounds_q100_q600_a(1,5) 1-bounds_q100_q600_a(3:5,5)' ; ...
                                150 300 J_q_K150_a(2) 1-bounds_q150_q300_a(1,5) 1-bounds_q150_q300_a(3:5,5)' ; ...
                                150 600 J_q_K150_a(2) 1-bounds_q150_q600_a(1,5) 1-bounds_q150_q600_a(3:5,5)' ; ...
                                150 900 J_q_K150_a(2) 1-bounds_q150_q900_a(1,5) 1-bounds_q150_q900_a(3:5,5)' ; ...
                                150 900 J_r_K150_a(2) 1-bounds_r150_r900_a(1,5) 1-bounds_r150_r900_a(3:5,5)' ] ;

outsheet(bounds_a,'K1,K2,J,overall,one_call,two_calls,three_calls','../results/grid_sensitivity_agcv.csv');


% III. NUNLEY

% a. First step moment estimates (K1)
[ests_q_K050_n,J_q_K050_n,~] = qp_ests(         nunley,                   grid_q_K050(:,1),grid_q_K050(:,2),0,ones(size(grid_q_K050(:,1))));
[ests_q_K100_n,J_q_K100_n,~] = qp_ests(         nunley,                   grid_q_K100(:,1),grid_q_K100(:,2),0,ones(size(grid_q_K100(:,1))));
[ests_q_K150_n,J_q_K150_n,~] = qp_ests(         nunley,                   grid_q_K150(:,1),grid_q_K150(:,2),0,ones(size(grid_q_K150(:,1))));
[ests_r_K150_n,J_r_K150_n,~] = qp_ests(         nunley,                   grid_r_K150(:,1),grid_r_K150(:,2),0,ones(size(grid_r_K150(:,1))));

% b. Second step bound estimates (K2>K1)
[bounds_q050_q200_n]         = lp_bounds_tronly(nunley,ests_q_K050_n(:,7),grid_q_K200(:,1),grid_q_K200(:,2),  ones(size(grid_q_K200(:,1))));
[bounds_q100_q200_n]         = lp_bounds_tronly(nunley,ests_q_K100_n(:,7),grid_q_K200(:,1),grid_q_K200(:,2),  ones(size(grid_q_K200(:,1))));
[bounds_q100_q400_n]         = lp_bounds_tronly(nunley,ests_q_K100_n(:,7),grid_q_K400(:,1),grid_q_K400(:,2),  ones(size(grid_q_K400(:,1))));
[bounds_q100_q600_n]         = lp_bounds_tronly(nunley,ests_q_K100_n(:,7),grid_q_K600(:,1),grid_q_K600(:,2),  ones(size(grid_q_K600(:,1))));
[bounds_q150_q300_n]         = lp_bounds_tronly(nunley,ests_q_K150_n(:,7),grid_q_K300(:,1),grid_q_K300(:,2),  ones(size(grid_q_K300(:,1))));
[bounds_q150_q600_n]         = lp_bounds_tronly(nunley,ests_q_K150_n(:,7),grid_q_K600(:,1),grid_q_K600(:,2),  ones(size(grid_q_K600(:,1))));
[bounds_q150_q900_n]         = lp_bounds_tronly(nunley,ests_q_K150_n(:,7),grid_q_K900(:,1),grid_q_K900(:,2),  ones(size(grid_q_K900(:,1))));
[bounds_r150_r900_n]         = lp_bounds_tronly(nunley,ests_r_K150_n(:,7),grid_r_K900(:,1),grid_r_K900(:,2),  ones(size(grid_r_K900(:,1))));

% c. Report Results
bounds_n                     = [ 50 200 J_q_K050_n(2) 1-bounds_q050_q200_n(1,5) 1-bounds_q050_q200_n(8:10,5)' ; ...
                                100 200 J_q_K100_n(2) 1-bounds_q100_q200_n(1,5) 1-bounds_q100_q200_n(8:10,5)' ; ...
                                100 400 J_q_K100_n(2) 1-bounds_q100_q400_n(1,5) 1-bounds_q100_q400_n(8:10,5)' ; ...
                                100 600 J_q_K100_n(2) 1-bounds_q100_q600_n(1,5) 1-bounds_q100_q600_n(8:10,5)' ; ...
                                150 300 J_q_K150_n(2) 1-bounds_q150_q300_n(1,5) 1-bounds_q150_q300_n(8:10,5)' ; ...
                                150 600 J_q_K150_n(2) 1-bounds_q150_q600_n(1,5) 1-bounds_q150_q600_n(8:10,5)' ; ...
                                150 900 J_q_K150_n(2) 1-bounds_q150_q900_n(1,5) 1-bounds_q150_q900_n(8:10,5)' ; ...
                                150 900 J_r_K150_n(2) 1-bounds_r150_r900_n(1,5) 1-bounds_r150_r900_n(8:10,5)' ] ;

outsheet(bounds_n,'K1,K2,J,overall,one_call,two_calls,three_calls','../results/grid_sensitivity_nunley.csv');
