function [varargout] = e_send_pairs(params, k, prior_params, history, ep_w, ep_b, recursion, max_recursion, value_dict)
	% Function computes the expected value function b
	% params -- vector of auditor parameters [gamma kappa c delta]
	% history -- vector of previous trials (possibly all zero) as [N_white rate_white N_black rate_black]
	% ep_w, ep_b, expected probability of acceptances based on updated prior 
	% prior -- vector of parameters governing prior distribution of p_b, p_w (shape depends on prior)
	% prior_params -- parameters of alpha_j normal distribution for type1 and type2, respectively

	% First increment recursion counter for maximum depth  
	recursion = recursion + 2;
		% Need to do by 2 here because we are sending pairs

	% Column offset for types in history:
	kc = (k-1)*4;

	% Then proceed
	% With probability ep_w*ep_b, both applications are accepted
	new_hist = history;
	new_hist(1+kc) = new_hist(1+kc) + 1;
	new_hist(2+kc) = (history(1+kc)*history(2+kc) + 1) / (history(1+kc) + 1);
	new_hist(3+kc) = new_hist(3+kc) + 1;
	new_hist(4+kc) = (history(3+kc)*history(4+kc) + 1) / (history(3+kc) + 1);
	[t c vd] = policy_pairs(params, new_hist, prior_params, recursion, max_recursion, value_dict);
	val = t*ep_w(k)*ep_b(k);

	% And with probability (1-ep_w)*(1-ep_b), both are rejected
	new_hist = history;
	new_hist(1+kc) = new_hist(1+kc) + 1;
	new_hist(2+kc) = (history(1+kc)*history(2+kc)) / (history(1+kc) + 1);
	new_hist(3+kc) = new_hist(3+kc) + 1;
	new_hist(4+kc) = (history(3+kc)*history(4+kc)) / (history(3+kc) + 1);
	[t c value_dict] = policy_pairs(params, new_hist, prior_params, recursion, max_recursion, vd);
	val = val + t*(1-ep_w(k))*(1-ep_b(k));

	% With probability ep_w*(1-ep_b), white accepted and black rejeected
	new_hist = history;
	new_hist(1+kc) = new_hist(1+kc) + 1;
	new_hist(2+kc) = (history(1+kc)*history(2+kc) + 1) / (history(1+kc) + 1);	
	new_hist(3+kc) = new_hist(3+kc) + 1;
	new_hist(4+kc) = (history(3+kc)*history(4+kc)) / (history(3+kc) + 1);
	[t c vd] = policy_pairs(params, new_hist, prior_params, recursion, max_recursion, value_dict);
	val = val + t*ep_w(k)*(1-ep_b(k));

	% And with probability (1-ep_w)*ep_b, white rejected and black accepted
	new_hist = history;
	new_hist(1+kc) = new_hist(1+kc) + 1;
	new_hist(2+kc) = (history(1+kc)*history(2+kc)) / (history(1+kc) + 1);		
	new_hist(3+kc) = new_hist(3+kc) + 1;
	new_hist(4+kc) = (history(3+kc)*history(4+kc) + 1) / (history(3+kc) + 1);
	[t c value_dict] = policy_pairs(params, new_hist, prior_params, recursion, max_recursion, vd);
	val = val + t*(1-ep_w(k))*ep_b(k);

	varargout = {val; value_dict};

end



