function [varargout] = policy_singles(params, history, prior_params, recursion, max_recursion, value_dict)
	% Function computes the value of the value function based on...
	% params -- vector of auditor parameters [gamma kappa c delta]
	% history -- vector of previous trials (possibly all zero) as [N_white rate_white N_black rate_black]
	% prior -- vector of parameters governing prior distribution of p_b, p_w (shape depends on prior)
	% prior_params -- parameters of alpha_j normal distribution for type1 and type2, respectively, then beta and beta_share

	% Note: The value function code here requires that all the auditors parameters are positive and that delta in (0,1)
	% You also want to ensure that c < delta * gamma to make the problem interesting

	%%% 0) Define a few variables based on the inputs
	gamma = params(1);
	kappa = params(2);
	c = params(3);
	delta = params(4);
	sim = 100;

	num_xbs = size(prior_params(9:end),2);

	%%% 1) First update prior based on history and save posterior
	[prob_disc ep_w ep_b post_odds bayes_factor] = bayes_normal(sim, prior_params, history);
				% note that ep_w and ep_b are both vectors of dim num_xbs

	%%% 2) Now get maximum recursively
	% First check if we have solved this problem already
	vd_rel = value_dict(:,size(history,2)+1) == recursion;
	[checked c_loc] = ismember(history, value_dict(vd_rel,1:4*num_xbs), 'rows');

	% Then, if e_accuse > -c + delta * gamma, it cant make sense to keep sampling
	e_accuse = (gamma + kappa)*prob_disc - kappa;
	if e_accuse > (-c + delta*gamma)
		[mval option] = max([repmat([-Inf -Inf],1,num_xbs) e_accuse 0]);

	% Send a maximum of k additional apps / look max k into the future
	elseif recursion >= max_recursion	
		[mval option] = max([repmat([-Inf -Inf],1,num_xbs) e_accuse 0]);
	
	% Otherwise use the option from the value dict	
	elseif sum(checked) > 0
		% tmp_vid = value_dict(vd_rel,:);
		% mval = tmp_vid(c_loc,4*num_xbs+2);
		% option = tmp_vid(c_loc,4*num_xbs+3);

		tmp_vid = find(vd_rel == 1,c_loc,'first');
		mval = value_dict(tmp_vid(end),4*num_xbs+2);
		option = value_dict(tmp_vid(end),4*num_xbs+3);

	% Otherwise evalulate our options		
	else
		vdb = value_dict;
		tostore = nan(1,2*num_xbs);
		for k = 1:num_xbs
			[esw vdw] = e_send_singles(0, k, params, prior_params, history, ep_w, ep_b, recursion, max_recursion, vdb);
			tostore(2*(k-1)+1) = -c + delta*esw;
			[esb vdb] = e_send_singles(1, k, params, prior_params, history, ep_w, ep_b, recursion, max_recursion, vdw);	
			tostore(2*(k-1)+2) =  -c + delta*esb;	
		end

		[mval option] = max([tostore e_accuse 0]);
		%value_dict = unique([vdb; history recursion mval option],'rows');
		value_dict = [vdb; history recursion mval option];
	end

	varargout = {mval; option; value_dict; prob_disc; post_odds; bayes_factor};
end



