function ans = policy_test_trace_curves_stupd_par(num_initial_pairs, max_depth, pairs, xbs, randomize)
tic
%%% Test out the policy here
% Set seed
rng(6583939)

try	
	num_initial_pairs = str2num(num_initial_pairs)
	max_depth = str2num(max_depth)
	pairs = str2num(pairs)
	xbs = str2num(xbs)
	randomize = str2num(randomize)
	if max_depth > 30
		warning('max depth beyond possible draws limit')
	end
catch
	warning('failed to find max depth and initial pairs')
	num_initial_pairs = 0
	max_depth = 10
	pairs = 1
	xbs = 1
	randomize = 0
end

%%% 1) Construct a sample of firms using prior DGP
num_firms = 5000;
num_sims = 100;


% Initialize prior parameters
%prior_params = [-4.931 4.988 0 4.983 4.046 -1.586 0 0 0]
prior_params = [-4.670 4.716 0 4.716 3.498 -1.518 0 0 0]
if xbs == 2
	%prior_params = [-4.931 4.988 0 4.983 4.046 -1.586 0 0 -.50 .50]
	prior_params = [-4.670 4.716 0 4.716 3.498 -1.518 0 0 -.51 .51]
end

% Declare number of covariate bins
cov_params = prior_params(9:end)
cov_bins = size(cov_params,2)

% Calculate unconditional prior share D  
prd = @(a) (1 + exp(-(prior_params(6) + prior_params(7)*a))).^-1 .* ...
			normpdf(a,prior_params(1),prior_params(2));
prior_params(8) = integral(prd,-Inf,Inf);

% Set firm types and probabilities
firm_alphas = normrnd(prior_params(1),prior_params(2),num_firms,1);
firm_D_probs = (1 + exp(-(prior_params(6) + prior_params(7)*firm_alphas))).^-1;
firm_types = binornd(1, firm_D_probs, num_firms,1);

p_w = zeros(num_firms,cov_bins);
p_b = zeros(num_firms,cov_bins);
for k = 1:cov_bins
	p_w(:,k) = arrayfun(@(x) (1+exp(-x - cov_params(k)))^-1, firm_alphas);
	p_b(:,k) = (1-firm_types) .* p_w(:,k) + firm_types .* arrayfun(@(x) (1+exp(-x- cov_params(k)))^-1, firm_alphas - prior_params(5));
end

% Generate draws of all possible squences for each firm and race / type combination
possible_draws = zeros(num_firms,30,2*cov_bins);
for k = 1:cov_bins
	possible_draws(:,:,1+2*(k-1)) = binornd(1,repmat(p_w(:,k),1,30));
	possible_draws(:,:,2+2*(k-1)) = binornd(1,repmat(p_b(:,k),1,30));
end 

% Select part of squence we need for this simulation
%possible_draws = possible_draws(:,1:max_depth,:); 

%%% 2) Generate initial histories based on firm probabilities
histories = zeros(num_firms,4*cov_bins);

% If randomize = 0, you get num_initial_pairs for each covariate type
if randomize == 0
	for k = 1:cov_bins
		histories(:,1+4*(k-1)) = num_initial_pairs;
		histories(:,3+4*(k-1)) = num_initial_pairs;
		
		% Correct for chattering in application draws
		histories(:,2+4*(k-1)) = sum(possible_draws(:,1:num_initial_pairs,1+2*(k-1)),2) / num_initial_pairs;
		histories(:,4+4*(k-1)) = sum(possible_draws(:,1:num_initial_pairs,2+2*(k-1)),2) / num_initial_pairs;
	end

% Otherwise we have to distribute initial pairs among types randomly
else
	choices = zeros(num_firms,cov_bins);
	choices(:,1) = randi([0 num_initial_pairs],num_firms,1);
	for k = 2:cov_bins
		for j = 1:num_firms
			choices(j,k) = randi([0 (num_initial_pairs-sum(choices(j,1:k-1)))],1,1);
		end
	end
	choices(:,end) = num_initial_pairs - sum(choices(:,1:cov_bins-1),2);
	
	for k = 1:cov_bins
		histories(:,1+4*(k-1)) = choices(:,k);
		histories(:,3+4*(k-1)) = choices(:,k);

		for p = 1:num_initial_pairs
			% Correct for chattering in application draws
			histories(choices(:,k) == p,2+4*(k-1)) = sum(possible_draws(choices(:,k) == p,1:p,1+2*(k-1)),2) / p;
			histories(choices(:,k) == p,4+4*(k-1)) = sum(possible_draws(choices(:,k) == p,1:p,2+2*(k-1)),2) / p;
		end
	end
end

% Replace NaNs with zeros if needed
histories(isnan(histories)) = 0;

orig_histories = histories;

%%% 3) Simulate auditors problem, using cost in top value
% Reset histories
histories = orig_histories;

uni = unique(histories,'rows');
indicators = zeros(num_firms,size(uni,1));
for type = 1:size(uni,1)
	indicators(:,type) = sum(abs(histories - uni(type,:)),2) == 0;
end

uniresults = zeros(size(uni,1),1);
for row = 1:size(uni,1)
	p = bayes_normal(num_sims, prior_params, uni(row,:));
	uniresults(row) = p;
end

initial_ps = indicators*uniresults;

% Do initial evaluation using just the unique histories
params = [1000 1000 0.5 1];		% cost here is 0.5 because sending 1/2 an pair
value_dict = nan(0,4*cov_bins + 1 + 2);
	% this thing stores history, recursion, and choice, max
	% so total dim = 4*cov_bins + 1 + 2

uni = unique(histories,'rows');
indicators = zeros(num_firms,size(uni,1));
for type = 1:size(uni,1)
	indicators(:,type) = sum(abs(histories - uni(type,:)),2) == 0;
end

uniresults = zeros(size(uni,1),2);
for row = 1:size(uni,1)
	if pairs == 1
		[t c vd] = policy_pairs(params, uni(row,:), prior_params, sum(uni(row,1:2:4*cov_bins)), max_depth, value_dict);
	else
		[t c vd] = policy_singles(params, uni(row,:), prior_params, sum(uni(row,1:2:4*cov_bins)), max_depth, value_dict);
	end
	uniresults(row,:) = [t c];
	%assert(sum(size(vd) == size(unique(vd,'rows'))) == 2)
	%value_dict = unique([value_dict ; vd], 'rows');
	value_dict = [value_dict ; vd];
end

results = indicators*uniresults;
%orig_results = results;

%history_accumulator = [uni uniresults];

% If some firms should be sampled again, do so
while sum(results(:,2) <= 2*cov_bins) > 0
	% Loop over the possibile responses
	for k = 1:cov_bins
		kc = 4*(k-1);

		% First the white choice
		ind = results(:,2) == 2*k-1;
		if sum(ind) > 0
			tograb = histories(ind,1+kc)+1;
			selector = zeros(sum(ind),max_depth);
			for type = 1:max_depth
				selector(:,type) = (tograb == type);
			end
			toadd = sum(possible_draws(ind,:,1+2*(k-1)).*selector,2);
			histories(ind,2+kc) = (histories(ind,1+kc).*histories(ind,2+kc) + toadd) ./ (histories(ind,1+kc)+1);
			histories(ind,1+kc) = histories(ind,1+kc) + 1;
		end

		% Now for choices to send_black, with correction for pairs
		ind = results(:,2) == 2*k-pairs;
		if sum(ind) > 0
			tograb = histories(ind,3+kc)+1;
			selector = zeros(sum(ind),max_depth);
			for type = 1:max_depth
				selector(:,type) = (tograb == type);
			end
			toadd = sum(possible_draws(ind,:,2+2*(k-1)).*selector,2);
			histories(ind,4+kc) = (histories(ind,3+kc).*histories(ind,4+kc) + toadd) ./ (histories(ind,3+kc)+1);
			histories(ind,3+kc) = histories(ind,3+kc) + 1;
		end
	end	

	% Now go over the results again for everyone who wanted to resample
	ind = results(:,2) <= 2*cov_bins;
	uni = unique(histories(ind,:),'rows');
	indicators = zeros(num_firms,size(uni,1));
	for type = 1:size(uni,1)
		indicators(:,type) = sum(abs(histories - uni(type,:)),2) == 0;
	end

	uniresults = zeros(size(uni,1),2);
	for row = 1:size(uni,1)
		if pairs == 1
			[t c vd] = policy_pairs(params, uni(row,:), prior_params, sum(uni(row,1:2:4*cov_bins)), max_depth, value_dict);
		else
			[t c vd] = policy_singles(params, uni(row,:), prior_params, sum(uni(row,1:2:4*cov_bins)), max_depth, value_dict);
		end
		uniresults(row,:) = [t c];
		value_dict = unique([value_dict ; vd],'rows');
	end

	tmpresults = indicators*uniresults;

	results(ind,:) = tmpresults(ind,:);
	%history_accumulator = [history_accumulator; uni uniresults];	
end

% Get total payout
apps_sent = sum(histories(:,1:2:cov_bins*4),2);
costs = params(3)*apps_sent;
benefits = zeros(num_firms,1) + (results(:,2) == 2*cov_bins+1).*firm_types*params(1) - (results(:,2) == 2*cov_bins+1).*(1-firm_types)*params(2);
costben = benefits - costs;

% Get a few statistics on accusations
tot_payout = sum(costben);

% Collect share parameters required and then add to overall results
share_d = sum(sum(firm_types == 1,2)) / num_firms;
share_discrim_accused = mean(results(firm_types == 1,2) == 2*cov_bins+1);
share_non_discrim_acquit = mean(results(firm_types == 0,2) ~= 2*cov_bins+1);

tot_discrim_accused = sum(results(firm_types == 1,2) == 2*cov_bins+1);
tot_non_discrim_acquit = sum(results(firm_types == 0,2) ~= 2*cov_bins+1);

apps_sent_per_firm = sum(sum(histories(:,1:2:cov_bins*4))) / num_firms;
total_apps_sent = sum(sum(histories(:,1:2:4*cov_bins)));

share_firms_resamp = mean(histories(:,1) > num_initial_pairs);
mean_resamps = mean(histories(histories(:,1) > num_initial_pairs,1) - num_initial_pairs);
max_resamps = max(histories(histories(:,1) > num_initial_pairs,1) - num_initial_pairs);

final_results = [params apps_sent_per_firm total_apps_sent tot_payout share_d share_discrim_accused share_non_discrim_acquit tot_discrim_accused tot_non_discrim_acquit share_firms_resamp mean_resamps max_resamps]


% Save to spreadsheet
outname = sprintf('results/nochat_%sfirms_%scovtypes_%sipairs_%sdepth_%spairs_%srandomize_%s_%s_%s_%s.csv', num2str(num_firms), num2str(cov_bins), num2str(num_initial_pairs), num2str(max_depth), num2str(pairs), num2str(randomize), num2str(params(1)), num2str(params(2)), num2str(params(3)), num2str(params(4)));
fid = fopen(outname,'w');
names = {'gamma' 'kappa' 'c' 'delta' 'apps_sent_per_firm' 'total_apps_sent' 'tot_payout' 'share_d' 'share_d_accused' 'share_nond_acquit' 'tot_d_accused' 'tot_non_d_acquit' 'share_firms_resamp' 'mean_resamps' 'max_resamps'};
fprintf(fid, '%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s\n', names{1,:});
fclose(fid);
dlmwrite(outname, final_results, 'delimiter', ',', '-append');


toc
end


